aboutsummaryrefslogtreecommitdiff
path: root/gcc/config/alpha/alpha.c
diff options
context:
space:
mode:
authorKazu Hirata <kazu@cs.umass.edu>2002-09-17 23:10:04 +0000
committerKazu Hirata <kazu@gcc.gnu.org>2002-09-17 23:10:04 +0000
commit825dda426b6951e40f7b0f6c8ef86e6aad86740a (patch)
tree8bbd60963b5ab609c8683955c3761d6dde0daf0f /gcc/config/alpha/alpha.c
parent8e16ab99953149a0936735618e6d26b79651a1b3 (diff)
downloadgcc-825dda426b6951e40f7b0f6c8ef86e6aad86740a.zip
gcc-825dda426b6951e40f7b0f6c8ef86e6aad86740a.tar.gz
gcc-825dda426b6951e40f7b0f6c8ef86e6aad86740a.tar.bz2
alpha.c: Follow spelling conventions.
* config/alpha/alpha.c: Follow spelling conventions. * config/alpha/alpha.h: Likewise. * config/alpha/alpha.md: Likewise. * config/arc/arc.h: Likewise. * config/arm/arm.c: Likewise. * config/arm/arm.h: Likewise. * config/arm/arm.md: Likewise. * config/arm/pe.c: Likewise. * config/arm/unknown-elf.h: Likewise. * config/avr/avr.c: Likewise. * config/avr/avr.h: Likewise. * config/c4x/c4x.c: Likewise. * config/cris/cris.c: Likewise. * config/cris/cris.h: Likewise. From-SVN: r57266
Diffstat (limited to 'gcc/config/alpha/alpha.c')
-rw-r--r--gcc/config/alpha/alpha.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gcc/config/alpha/alpha.c b/gcc/config/alpha/alpha.c
index dcd377f..f7963be 100644
--- a/gcc/config/alpha/alpha.c
+++ b/gcc/config/alpha/alpha.c
@@ -88,7 +88,7 @@ const char *alpha_tls_size_string; /* -mtls-size=[16|32|64] */
struct alpha_compare alpha_compare;
/* Non-zero if inside of a function, because the Alpha asm can't
handle .files inside of functions. */
static int inside_function = FALSE;
@@ -3478,7 +3478,7 @@ alpha_emit_setcc (code)
/* Rewrite a comparison against zero CMP of the form
(CODE (cc0) (const_int 0)) so it can be written validly in
a conditional move (if_then_else CMP ...).
- If both of the operands that set cc0 are non-zero we must emit
+ If both of the operands that set cc0 are nonzero we must emit
an insn to perform the compare (it can't be done within
the conditional move). */
rtx
@@ -3510,7 +3510,7 @@ alpha_emit_conditional_move (cmp, mode)
/* If we have fp<->int register move instructions, do a cmov by
performing the comparison in fp registers, and move the
- zero/non-zero value to integer registers, where we can then
+ zero/nonzero value to integer registers, where we can then
use a normal cmov, or vice-versa. */
switch (code)
@@ -4042,7 +4042,7 @@ alpha_split_tfmode_frobsign (operands, operation)
alpha_split_tfmode_pair (operands);
- /* Detect three flavours of operand overlap. */
+ /* Detect three flavors of operand overlap. */
move = 1;
if (rtx_equal_p (operands[0], operands[2]))
move = 0;
@@ -88,7 +88,7 @@ const char *alpha_tls_size_string; /* -mtls-size=[16|32|64] */
struct alpha_compare alpha_compare;
-/* Non-zero if inside of a function, because the Alpha asm can't
+/* Nonzero if inside of a function, because the Alpha asm can't
handle .files inside of functions. */
static int inside_function = FALSE;